.. uwacan documentation master file, created by
   sphinx-quickstart on Tue Jul 30 15:29:15 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

####################
Uwacan documentation
####################

.. toctree::
   :maxdepth: 1

   User Guide <user/index>
   API Reference <reference/index>
